Module socket

Module socket 

Structs

SmolSocketsmol-socket
A Socket that uses a UnixStream from the async_net crate internally.
TokioSockettokio-socket
A Socket that uses a UnixStream from the tokio crate internally.

Traits

Socket
The Socket trait is a basic abstraction over an underlying asynchronous Unix socket connection used by this crate to connect to fcnetd. This allows for different async I/O implementations to be used interchangeably by implementing this trait.