Module socket
fcnetd_
client
0.2.3
Module socket
Module Items
Structs
Traits
In crate fcnetd_
client
fcnetd_client
Module
socket
Structs

Smol
Socket
smol-socket
A
Socket
that uses a
UnixStream
from the
async_net
crate internally.
Tokio
Socket
tokio-socket
A
Socket
that uses a
UnixStream
from the
tokio
crate internally.
Traits

Socket
The
Socket
trait is a basic abstraction over an underlying asynchronous Unix socket connection used by this crate to connect to fcnetd. This allows for different async I/O implementations to be used interchangeably by implementing this trait.